# Changelog

* **1.0.2** (2023-05-04)
  * Updated documentation

* **1.0.1** (2023-05-03)
  * Added missing translations
  * Updated documentation

* **1.0.0** (2023-05-01)
  * Release as a separate package at PyPI (was before a part of [ai-django-core](https://pypi.org/project/ai-django-core/))
